@@ -88,8 +88,10 @@ class MapfwBenchmarker:
 
         self.status = {"state": "RUNNING", "data": {"problem_states": [0 for _ in self.problems]}}
 
-def get_all_benchmarks(without=None):
+def get_all_benchmarks(without:Union[int, iter]=None):
     if not without:
         without = []
+    without = [without] if isinstance(without, int) else without
+
     r = requests.get("https://mapfw.nl/benchmarks/list.json")
     return [problem for problem in r.json() if problem not in without]
\ No newline at end of file
